moonshine.models
================

.. automodule:: moonshine.models

.. currentmodule:: moonshine.models

.. rubric:: Classes

.. autosummary::
      :toctree: generated
      :nosignatures:
      :template: classtemplate.rst

      UNet

.. This file autogenerated by docs/source/conf.py
